@@ -1,8 +1,3 @@
-# $Id: /mirror/coderepos/lang/perl/Text-MeCab/trunk/lib/Text/MeCab.pm 38117 2008-01-07T00:02:59.679302Z daisuke  $
-#
-# Copyright (c) 2006-2008 Daisuke Maki <daisuke@endeworks.jp>
-# All rights reserved.
-
 package Text::MeCab;
 use strict;
 use warnings;
@@ -11,7 +6,7 @@ use Exporter 'import';
 our ($VERSION, @ISA, %EXPORT_TAGS, @EXPORT_OK);
 BEGIN
 {
-    $VERSION = '0.20000_01';
+    $VERSION = '0.20007_01';
     if ($] > 5.006) {
         require XSLoader;
         XSLoader::load(__PACKAGE__, $VERSION);
@@ -91,9 +86,6 @@ Text::MeCab - Alternate Interface To libmecab
   use Text::MeCab qw(:all);
   use Text::MeCab qw(MECAB_NOR_NODE);
 
-  # want to use a command line arguments?
-  my $mecab = Text::MeCab->new("--userdic=/foo/bar/baz", "-P");
-
   # check what mecab version we compiled against?
   print "Compiled with ", &Text::MeCab::MECAB_VERSION, "\n";
 
@@ -272,10 +264,21 @@ The version number detected at compile time of Text::MeCab.
 
 =head2 MECAB_UNK_DIC
 
+=head2 MECAB_CONFIG
+
+Path to mecab-config, if available.
+
 =head1 SEE ALSO
 
 http://mecab.sourceforge.ne.jp
 
+=head1 LICENSE
+
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
+
+See http://www.perl.com/perl/misc/Artistic.html
+
 =head1 AUTHOR
 
 Copyright (c) 2006-2008 Daisuke Maki E<lt>daisuke@endeworks.jpE<gt>
